TransactionLog

Trait TransactionLog 

pub trait TransactionLog: Send + Sync {
    // Required methods
    fn append(&self, record: &TxRecord) -> Result<(), LogError>;
    fn tx_range(
        &self,
        start: u64,
        end: Option<u64>,
    ) -> Result<Vec<TxRecord>, LogError>;

    // Provided method
    fn replay(&self) -> Result<Vec<TxRecord>, LogError> { ... }
}
Common transaction log interface.

Required Methods

fn append(&self, record: &TxRecord) -> Result<(), LogError>

Durably appends exactly the next transaction.

Errors

Returns an error for I/O failure, corruption, or a non-contiguous t.

fn tx_range( &self, start: u64, end: Option<u64>, ) -> Result<Vec<TxRecord>, LogError>

Returns records in the half-open transaction range [start, end).

Errors

Returns an error when stored records cannot be read or decoded.

Provided Methods

fn replay(&self) -> Result<Vec<TxRecord>, LogError>

Replays every committed record.

Errors

Returns an error when stored records cannot be read or decoded.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors